@@ -3,21 +3,10 @@
 import { Crates } from "./helpers/mod.ts";
 
 const crates = new Crates();
-const deno_graph = crates.get("deno_graph");
-const deno_doc = crates.get("deno_doc");
-const deno_lint = crates.get("deno_lint");
-const dprint_plugin_typescript = crates.get("dprint-plugin-typescript");
-const deno = crates.get("deno");
 
 // Ensure repos are latest main
 for (
-  const crate of [
-    deno_graph,
-    deno_doc,
-    deno_lint,
-    dprint_plugin_typescript,
-    deno,
-  ]
+  const crate of crates.nonDenoAstCrates()
 ) {
   console.log(`Setting up ${crate.name}...`);
   if (await crate.hasLocalChanges()) {
